@@ -190,12 +190,7 @@ class Ebus:
             yield msg
 
     async def get_state(self):
-        """
-        Return state string.
-
-        States are:
-          TODO
-        """
+        """Return state string."""
         _LOGGER.info("get_state()")
         try:
             lines = tuple([line async for line in self._request("state")])
@@ -207,6 +202,11 @@ class Ebus:
         except ConnectionTimeout:
             return "no ebusd connection"
 
+    async def is_online(self):
+        """Return if we are online."""
+        state = await get_state()
+        return state == "ok"
+
     async def cmd(self, cmd, infinite=False, check=False):
         """Send `cmd` to EBUSD and Receive Response."""
         _LOGGER.info(f"cmd({cmd!r}, infinite={infinite!r}, check={check!r})")
